pub struct SurfaceInfo {
pub size: Size2D<i32>,
pub id: SurfaceID,
pub context_id: ContextID,
pub framebuffer_object: Option<Framebuffer>,
}Expand description
Various data about the surface.
Fields
size: Size2D<i32>The surface’s size, in device pixels.
id: SurfaceIDThe ID of the surface. This should be globally unique for each currently-allocated surface.
context_id: ContextIDThe ID of the context that this surface belongs to.
framebuffer_object: Option<Framebuffer>The OpenGL framebuffer object that can be used to render to this surface.
This is only valid when the surface is actually attached to a context.